/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __TIZEN_CAPI_NETWORK_USER_AWARENESS_INTERNAL_H__
#define __TIZEN_CAPI_NETWORK_USER_AWARENESS_INTERNAL_H__

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @file user-awareness.h
 */

/**
 * @ingroup CAPI_NETWORK_FRAMEWORK
 * @addtogroup CAPI_NETWORK_UA_MODULE User Awareness
 * @{
 */

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Sets the brightness absence and presence threshold level.
 * @since_tizen 5.5
 *
 * @param[in] handle The monitor handle
 * @param[in] presence_threshold Presence threshold (Unit. Lux).
 * @param[in] absence_threshold Absence threshold (Unit. Lux).
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 * @retval #UA_ERROR_INVALID_PARAMETER Invalid parameter
 */
int ua_monitor_set_brightness_threshold(ua_monitor_h handle,
	int presence_threshold, int absence_threshold);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Enables low power mode for host device.
 * @since_tizen 5.5
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 */
int ua_enable_low_power_mode(void);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Disables low power mode for host device.
 * @since_tizen 5.5
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 */
int ua_disable_low_power_mode(void);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Sets low power mode for each sensor.
 * @since_tizen 5.5
 *
 * @param[in] bitmask The sensor bitmask
 * @param[in] on_off Low power mode enable or not
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 */
int ua_set_low_power_mode(unsigned int bitmask, bool on_off);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Gets the current detection parameter set for sensors.
 * @since_tizen 5.5
 *
 * @param[out] cycle Time in seconds after which user detection procedure
 *             (BLE scan/ARPing etc.) is repeated.
 * @param[out] period Time in second for which User detection procedure is executed.
 * @param[out] retries Number of retries to detect users before reporting absence.
 *             A non-detection count is maintained against each user. After
 *             each detection cycle, if presence is detected, then count is
 *             reset to 0 and Presence is reported. Else, the count is incremented
 *             and once count reaches the retries value, Absence is reported.
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 * @retval #UA_ERROR_INVALID_PARAMETER Invalid parameter
 */
int ua_get_detection_params(int *cycle, int *period, int *retries);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Sets the detection parameter for sensors. Invoking this will stop any onging
 * detection and set the new detection parameters and the restart detection again.
 * @since_tizen 5.5
 *
 * @param[in] cycle Time in seconds after which user detection procedure
 *            (BLE scan/ARPing etc.) is repeated.
 * @param[in] period Time in second for which User detection procedure is executed.
 * @param[in] retries Number of retries to detect users before reporting absence.
 *            A non-detection count is maintained against each user. After
 *            each detection cycle, if presence is detected, then count is
 *            reset to 0 and Presence is reported. Else, the count is incremented
 *            and once count reaches the retries value, Absence is reported.
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 * @retval #UA_ERROR_INVALID_PARAMETER Invalid parameter
 */
int ua_set_detection_params(int cycle, int period, int retries);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Sets the detection cycle parameter for service.
 * @since_tizen 5.5
 *
 * @remarks The value will be reset to default after reboot.
 *
 * @param[in] service Service handle for which detection cycle is getting configure.
 * @param[in] cycle_time Time in seconds after which user detection procedure
 *            (BLE scan/ARPing etc) is repeated. Minimum value of cycle_time
 *            is 300 seconds, Applications to send multiplier of 300 seconds only
 *            in this parameter. Example : 1*300 = 300 secs, 2*300 = 600 secs etc.).
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 * @retval #UA_ERROR_INVALID_PARAMETER Invalid parameter
 *
 * @see #UA_DETECTION_CYCLE_STEP
 * @see #UA_MIN_DETECTION_CYCLE
 * @see ua_get_detection_cycle()
 */
int ua_set_detection_cycle(ua_service_h service, unsigned int cycle_time);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Gets the current detection cycle parameter set for particular service.
 * @since_tizen 5.5
 *
 * @param[in] service Service handle for which detection cycle is getting configure.
 * @param[in] cycle_time Time in second after which user detection procedure
 *            (BLE scan/ARPing etc.) is repeated.
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 * @retval #UA_ERROR_INVALID_PARAMETER Invalid parameter
 *
 * @see ua_set_detection_cycle()
 */
int ua_get_detection_cycle(ua_service_h service, unsigned int* cycle_time);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Sets the detection window parameter for sensors.
 * @since_tizen 5.5
 *
 * @remarks The value will be reset to default after reboot.
 *
 * @param[in] window Time in seconds for which User detection procedure is executed.
 *            Maximum value of window is 290 seconds, Applications to send multiplier of
 *            10 seconds only in this parameter. Example : 1*10 = 10 secs, 2*10 = 20
 *            secs etc.).
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 * @retval #UA_ERROR_INVALID_PARAMETER Invalid parameter
 *
 * @see #UA_DETECTION_WINDOW_STEP
 * @see #UA_MAX_DETECTION_WINDOW
 * @see ua_get_detection_window()
 */
int ua_set_detection_window(unsigned int window);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Gets the current detection window parameter.
 * @since_tizen 5.5
 *
 * @param[in] window Time for which User detection procedure is executed.
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 * @retval #UA_ERROR_INVALID_PARAMETER Invalid parameter
 *
 * @see ua_set_detection_window()
 */
int ua_get_detection_window(unsigned int* window);

/**
 * @internal
 * @ingroup CAPI_NETWORK_UA_MODULE
 * @brief Resets database.
 * @since_tizen 5.5
 *
 * @return 0 on success, otherwise a negative error value
 * @retval #UA_ERROR_NONE Successful
 */
int ua_reset_database(void);

/**
 * @}
 */

#ifdef __cplusplus
}
#endif
#endif /* __TIZEN_CAPI_NETWORK_USER_AWARENESS_INTERNAL_H__ */

